NLSL: tridag Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Variables
tridag Module Reference

## Variables
integer, dimension(mxsite, mxspc), save | ixtd
integer, dimension(mxsite, mxspc), save | ltd
integer, dimension(mxsite, mxspc), save | modtd
integer, dimension(mxtdm), save | tdspec
integer, dimension(mxtdm), save | tdsite
integer, save | nexttd
integer, save | ntd
double complex, dimension(mxtdg), save | alpha
double complex, dimension(mxtdg), save | beta
double complex, dimension(mxdim), save | stv
double complex, dimension(mxdim), save | y

## Variable Documentation

double complex, dimension(mxtdg), save tridag::alpha

Definition at line 32 of file tridag.f90.

double complex, dimension(mxtdg), save tridag::beta

Definition at line 32 of file tridag.f90.

integer, dimension(mxsite,mxspc), save tridag::ixtd

Definition at line 28 of file tridag.f90.

integer, dimension(mxsite,mxspc), save tridag::ltd

Definition at line 28 of file tridag.f90.

integer, dimension(mxsite,mxspc), save tridag::modtd

Definition at line 28 of file tridag.f90.

integer, save tridag::nexttd

Definition at line 28 of file tridag.f90.

integer, save tridag::ntd

Definition at line 28 of file tridag.f90.

double complex, dimension(mxdim), save tridag::stv

Definition at line 32 of file tridag.f90.

integer, dimension(mxtdm), save tridag::tdsite

Definition at line 28 of file tridag.f90.

integer, dimension(mxtdm), save tridag::tdspec

Definition at line 28 of file tridag.f90.

double complex, dimension(mxdim), save tridag::y

Definition at line 32 of file tridag.f90.